@@ -33,20 +33,14 @@
 #ifndef __GDK_DIRECTFB_H__
 #define __GDK_DIRECTFB_H__
 
+/* This define disables some experimental code
+ */
+#define GDK_DIRECTFB_NO_EXPERIMENTS
+
 #include <cairo.h>
 #include <directfb.h>
 #include "gdk/gdkprivate.h"
 
-/* macro for a safe call to DirectFB functions */
-#define DFBCHECK(x...) \
-     {                                                                \
-          int err = x;                                                    \
-          if (err != DFB_OK) {                                        \
-               fprintf( stderr, "%s <%d>:\n\t", __FILE__, __LINE__ ); \
-               DirectFBErrorFatal( #x, err );                         \
-          }                                                           \
-     }
-
 
 extern GdkWindow * _gdk_parent_root;
 
@@ -86,10 +80,8 @@ GdkVisual * gdk_directfb_visual_by_format   (DFBSurfacePixelFormat  pixel_format
 IDirectFBWindow *gdk_directfb_window_lookup(GdkWindow *window);
 IDirectFBSurface *gdk_directfb_surface_lookup(GdkWindow *window);
 
-#if (DIRECTFB_MAJOR_VERSION >= 1)
 GdkWindow *gdk_directfb_create_child_window(GdkWindow *parent,
-                IDirectFBSurface *subsurface);
-#endif
+                                            IDirectFBSurface *subsurface);
 
 
 G_END_DECLS
