@@ -36,7 +36,7 @@
 #include "gdkinternals.h"
 #include "gdkkeysyms.h"
 
-#include <config.h>
+#include "config.h"
 
 guint _gdk_keymap_serial = 0;
 gboolean _gdk_keyboard_has_altgr = FALSE;
@@ -366,7 +366,6 @@ update_keymap (void)
 	  for (shift = 0; shift < 4; shift++)
 	    {
 	      guint *ksymp = keysym_tab + vk*4 + shift;
-	      guchar chars[2];
 	      
 	      set_shift_vks (key_state, shift);
 
@@ -384,22 +383,17 @@ update_keymap (void)
 		  wchar_t wcs[10];
 		  gint k;
 
+		  wcs[0] = wcs[1] = 0;
 		  k = ToUnicodeEx (vk, scancode, key_state,
 				   wcs, G_N_ELEMENTS (wcs),
 				   0, _gdk_input_locale);
 #if 0
-		  g_print ("ToUnicodeEx(%02x, %d: %d): %d, %04x %04x\n",
+		  g_print ("ToUnicodeEx(%#02x, %d: %d): %d, %04x %04x\n",
 			   vk, scancode, shift, k,
-			   (k != 0 ? wcs[0] : 0),
-			   (k >= 2 ? wcs[1] : 0));
+			   wcs[0], wcs[1]);
 #endif
 		  if (k == 1)
 		    *ksymp = gdk_unicode_to_keyval (wcs[0]);
-
-		  if (k == 1)
-		    {
-		      /* Keysym already stored above */
-		    }
 		  else if (k == -1)
 		    {
 		      guint keysym = gdk_unicode_to_keyval (wcs[0]);
@@ -510,7 +504,7 @@ gdk_keymap_get_direction (GdkKeymap *keymap)
 {
   update_keymap ();
 
-  switch (PRIMARYLANGID (LOWORD ((DWORD) _gdk_input_locale)))
+  switch (PRIMARYLANGID (LOWORD ((DWORD) (gintptr) _gdk_input_locale)))
     {
     case LANG_HEBREW:
     case LANG_ARABIC:
@@ -536,6 +530,12 @@ gdk_keymap_have_bidi_layouts (GdkKeymap *keymap)
   return FALSE;
 }
 
+gboolean
+gdk_keymap_get_caps_lock_state (GdkKeymap *keymap)
+{
+  return ((GetKeyState (VK_CAPITAL) & 1) != 0);
+}
+
 gboolean
 gdk_keymap_get_entries_for_keyval (GdkKeymap     *keymap,
                                    guint          keyval,
